Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Passport ¶
type Passport struct {
// ContractAddress contains address of passport contract
ContractAddress common.Address
// FirstOwner contains address of first passport owner
FirstOwner common.Address
// Blockchain specific contextual infos
Raw types.Log
}
Passport contains basic information about created passport
type PassportFilterOpts ¶
type PassportFilterOpts struct {
Start uint64 // Start of the queried range
End *uint64 // End of the range (nil = latest)
Passport []common.Address // Passport is a slice of passports to filter (nil = all passports)
Owner []common.Address // Owner is a slice of first owners to filter (nil = all owners)
Context context.Context // Network context to support cancellation and timeouts (nil = no timeout)
}
PassportFilterOpts is the collection of options to fine tune filtering for passports.
type PassportIterator ¶
type PassportIterator struct {
Passport *Passport // Passport containing the info of the last retrieved passport
// contains filtered or unexported fields
}
PassportIterator is returned from FilterPassports and is used to iterate over the passports and unpacked data for PassportCreated events raised by the PassportFactoryContract contract.
func (*PassportIterator) Close ¶
func (pit *PassportIterator) Close() error
Close terminates the iteration process, releasing any pending underlying resources.
func (*PassportIterator) Error ¶
func (pit *PassportIterator) Error() error
Error returns any retrieval or parsing error occurred during filtering.
func (*PassportIterator) Next ¶
func (pit *PassportIterator) Next() (next bool)
Next advances the iterator to the subsequent passport, returning whether there are any more passports found. In case of a retrieval or parsing error, false is returned and Error() can be queried for the exact failure.
func (*PassportIterator) ToSlice ¶
func (pit *PassportIterator) ToSlice() (ps []*Passport, err error)
ToSlice retrieves all passports and saves them into slice.
type Reader ¶
Reader retrieves data from passport factory
func (*Reader) FilterPassports ¶
func (r *Reader) FilterPassports(opts *PassportFilterOpts, passportFactoryAddress common.Address) (*PassportIterator, error)
FilterPassports retrieves passports from event log of passport factory.